dynamic_provider_registry

Function dynamic_provider_registry 

pub fn dynamic_provider_registry(
    service: SomaService,
) -> Result<ProviderRegistry>
Build a registry combining the static provider with file-backed providers loaded from the default provider directory (SOMA_PROVIDER_DIR or providers).