pub async fn dynamic_provider_registry_with_python(
service: SomaService,
python_runner: PythonRunnerSelection,
) -> Result<ProviderRegistry>Expand description
Builds a dynamic registry with an explicit Python execution strategy.
pub async fn dynamic_provider_registry_with_python(
service: SomaService,
python_runner: PythonRunnerSelection,
) -> Result<ProviderRegistry>Builds a dynamic registry with an explicit Python execution strategy.