pub struct ApplicationPorts {
pub gateway: Arc<dyn GatewayPort>,
pub codemode: Arc<dyn CodeModePort>,
pub openapi: Arc<dyn OpenApiPort>,
}Expand description
Bundle of the engine ports the application depends on.
Fields
gateway: Arc<dyn GatewayPort>MCP gateway engine port.
codemode: Arc<dyn CodeModePort>Code Mode engine port.
openapi: Arc<dyn OpenApiPort>OpenAPI engine port.
Implementations
Sourceimpl ApplicationPorts
impl ApplicationPorts
Builds a port bundle where every engine reports itself as unavailable.
Sourcepub fn with_gateway(self, gateway: Arc<dyn GatewayPort>) -> Self
pub fn with_gateway(self, gateway: Arc<dyn GatewayPort>) -> Self
Replaces the gateway port and returns the updated bundle.
Sourcepub fn with_codemode(self, codemode: Arc<dyn CodeModePort>) -> Self
pub fn with_codemode(self, codemode: Arc<dyn CodeModePort>) -> Self
Replaces the Code Mode port and returns the updated bundle.
Sourcepub fn with_openapi(self, openapi: Arc<dyn OpenApiPort>) -> Self
pub fn with_openapi(self, openapi: Arc<dyn OpenApiPort>) -> Self
Replaces the OpenAPI port and returns the updated bundle.