pub struct CatalogSnapshot {
pub id: String,
pub fingerprint: String,
pub catalogs: Vec<ProviderCatalog>,
}Expand description
Snapshot of the provider catalogs at a point in time.
Fields
id: StringIdentifier of this snapshot.
fingerprint: StringFingerprint of the catalog contents used for change detection.
catalogs: Vec<ProviderCatalog>Provider catalogs captured in the snapshot.